**Greetings!** 
`This is a python API, which is a wrapper class for the zomato's web based API
This API contains various functions
get_collections -> returns all restaurants in a given city
get_cuisines -> returns all cuisines types in a given city
get_establishment_types -> returns all establishment types in a given city
get_nearby_restaurants -> returns the nearby restaurants given your geo coordinates
restaurant_search -> returns dictionary of restaurants within a radius of your location and/or of cusine/s types
`
**Steps before using this API**
`Please "Generate API key" from https://developers.zomato.com/api#headline2`

**To Install this API**
`pip install zomato-distribution-api==0.1.3`
